@@ -58,19 +58,16 @@ module Numeric.Interval.Internal
 
 import Control.Exception as Exception
 import Data.Data
-import Data.Foldable hiding (minimum, maximum, elem, notElem
-#if __GLASGOW_HASKELL__ >= 710
-  , null
-#endif
-  )
 import Data.Function (on)
-import Data.Monoid
 #if __GLASGOW_HASKELL__ >= 704
 import GHC.Generics
 #endif
 import Numeric.Interval.Exception
 import Prelude hiding (null, elem, notElem)
 
+import qualified Data.Semigroup
+import qualified Data.Monoid
+
 -- $setup
 
 data Interval a = I !a !a | Empty deriving
@@ -85,10 +82,13 @@ data Interval a = I !a !a | Empty deriving
 #endif
   )
 
-instance Foldable Interval where
-  foldMap f (I a b) = f a `mappend` f b
-  foldMap _ Empty = mempty
-  {-# INLINE foldMap #-}
+-- | 'Data.Semigroup.<>' is 'hull'
+instance Ord a => Data.Semigroup.Semigroup (Interval a) where
+  (<>) = hull
+
+instance Ord a => Data.Monoid.Monoid (Interval a) where
+  mempty = empty
+  mappend = (Data.Semigroup.<>)
 
 infix 3 ...
 infixl 6 +/-
