@@ -23,6 +23,8 @@ module Numeric.Interval.NonEmpty
   , interval
   , whole
   , singleton
+  , member
+  , notMember
   , elem
   , notElem
   , inf
@@ -46,6 +48,10 @@ module Numeric.Interval.NonEmpty
   , scale, symmetric
   , idouble
   , ifloat
+  , iquot
+  , irem
+  , idiv
+  , imod
   ) where
 
 import Numeric.Interval.NonEmpty.Internal
