@@ -55,14 +55,13 @@ module Numeric.Interval.NonEmpty.Internal
 
 import Control.Exception as Exception
 import Data.Data
-import Data.Foldable hiding (minimum, maximum, elem, notElem)
-import Data.Monoid
 #if __GLASGOW_HASKELL__ >= 704
 import GHC.Generics
 #endif
-import Numeric.Interval.Exception
 import Prelude hiding (null, elem, notElem)
 
+import qualified Data.Semigroup
+
 -- $setup
 -- >>> import Test.QuickCheck.Arbitrary
 -- >>> import Test.QuickCheck.Gen hiding (scale)
@@ -91,9 +90,9 @@ data Interval a = I !a !a deriving
 #endif
   )
 
-instance Foldable Interval where
-  foldMap f (I a b) = f a `mappend` f b
-  {-# INLINE foldMap #-}
+-- | 'Data.Semigroup.<>' is 'hull'
+instance Ord a => Data.Semigroup.Semigroup (Interval a) where
+  (<>) = hull
 
 infix 3 ...
 
